@@ -26,6 +26,7 @@ from .extractors import (
     idiosyncrasies_search,
     img_search,
     json_search,
+    regex_parse,
     timestamp_search,
     try_date_expr,
     DATE_EXPRESSIONS,
@@ -91,6 +92,7 @@ DATE_ATTRIBUTES = {
     "created",
     "cxenseparse:recs:publishtime",
     "date",
+    "date_created",
     "date_published",
     "datecreated",
     "dateposted",
@@ -106,6 +108,8 @@ DATE_ATTRIBUTES = {
     "dcterms.issued",
     "dc:created",
     "dc:date",
+    "displaydate",
+    "doc_date",
     "gentime",
     # Open Graph: https://opengraphprotocol.org/
     "og:published_time",
@@ -129,10 +133,12 @@ PROPERTY_MODIFIED = {
     "datemodified",
     "dc.modified",
     "dcterms.modified",
+    "lastmodified",
     "modified_time",
     "og:article:modified_time",
     "og:updated_time",
     "release_date",
+    "revision_date",
     "updated_time",
 }
 
@@ -244,10 +250,8 @@ def examine_header(
         if "property" in elem.attrib and "content" in elem.attrib:
             attribute = elem.get("property").lower()
             # original date or modified date: override published_time
-            if (
-                original_date
-                and attribute in DATE_ATTRIBUTES
-                or original_date is not True
+            if (original_date and attribute in DATE_ATTRIBUTES) or (
+                not original_date
                 and (attribute in PROPERTY_MODIFIED or attribute in DATE_ATTRIBUTES)
             ):
                 LOGGER.debug("examining meta property: %s", logstring(elem))
@@ -339,7 +343,7 @@ def select_candidate(
     max_date: datetime,
 ) -> Optional[Match[str]]:
     """Select a candidate among the most frequent matches"""
-    match = None
+    match, year1, year2 = None, None, None
     # LOGGER.debug('occurrences: %s', occurrences)
     if len(occurrences) == 0 or len(occurrences) > MAX_POSSIBLE_CANDIDATES:
         return None
@@ -756,7 +760,7 @@ def search_page(
         yearpat=SLASHES_YEAR,
         earliest=min_date,
         latest=max_date,
-        tocomplete=True,
+        incomplete=True,
     )
     # revert DD-MM-YYYY patterns before sorting
     replacement = {}
@@ -812,7 +816,7 @@ def search_page(
         yearpat=MMYYYY_YEAR,
         earliest=min_date,
         latest=max_date,
-        tocomplete=original_date,
+        incomplete=original_date,
     )
     # revert DD-MM-YYYY patterns before sorting
     replacement = {}
@@ -840,14 +844,28 @@ def search_page(
     if result is not None:
         return result
 
-    # catchall
+    # try full-blown text regex on all HTML?
+    dateobject = regex_parse(htmlstring)
+    # todo: find all candidates and disambiguate?
+    if date_validator(
+        dateobject, outputformat, earliest=min_date, latest=max_date
+    ) is True and (
+        copyear == 0 or dateobject.year >= copyear  # type: ignore[union-attr]
+    ):
+        try:
+            LOGGER.debug("regex result on HTML: %s", dateobject)
+            return dateobject.strftime(outputformat)  # type: ignore
+        except ValueError as err:
+            LOGGER.error("value error during conversion: %s %s", dateobject, err)
+
+    # catchall: copyright mention
     if copyear != 0:
         LOGGER.debug("using copyright year as default")
         return convert_date(
             "-".join([str(copyear), "01", "01"]), "%Y-%m-%d", outputformat
         )
 
-    # 1 component, last try
+    # last resort: 1 component
     LOGGER.debug("switching to one component")
     bestmatch = search_pattern(
         htmlstring,
@@ -880,6 +898,7 @@ def find_date(
     verbose: bool = False,
     min_date: Optional[datetime] = None,
     max_date: Optional[datetime] = None,
+    deferred_url_extractor: bool = False,
 ) -> Optional[str]:
     """
     Extract dates from HTML documents using markup analysis and text patterns
@@ -912,6 +931,10 @@ def find_date(
     :param max_date:
         Set the latest acceptable date manually (YYYY-MM-DD format)
     :type max_date: string
+    :param deferred_url_extractor:
+        Use url extractor as backup only to prioritize full expressions,
+        e.g. of the type `%Y-%m-%d %H:%M:%S`
+    :type deferred_url_extractor: boolean
     :return: Returns a valid date expression as a string, or None
     """
 
@@ -931,12 +954,15 @@ def find_date(
 
     # URL
     if url is None:
-        # link canonical
+        # probe for canonical links
         for elem in tree.iterfind('.//link[@rel="canonical"]'):
             url = elem.get("href")
             if url is not None:
+                # break out of the loop
                 break
-    if url is not None:
+
+    # direct processing of URL info
+    if not deferred_url_extractor and url is not None:
         dateresult = extract_url_date(url, outputformat, min_date, max_date)
         if dateresult is not None:
             return dateresult
@@ -953,6 +979,12 @@ def find_date(
     if json_result is not None:
         return json_result
 
+    # deferred processing of URL info (may be moved even further down if necessary)
+    if url is not None and deferred_url_extractor:
+        dateresult = extract_url_date(url, outputformat, min_date, max_date)
+        if dateresult is not None:
+            return dateresult
+
     # try abbr elements
     abbr_result = examine_abbr_elements(
         tree, outputformat, extensive_search, original_date, min_date, max_date
@@ -993,7 +1025,7 @@ def find_date(
     try:
         cleaned_html = HTML_CLEANER.clean_html(tree)
     # rare LXML error: no NULL bytes or control characters
-    except ValueError:
+    except ValueError:  # pragma: no cover
         cleaned_html = tree
         LOGGER.error("lxml cleaner error")
 
