@@ -112,18 +112,18 @@ YM_PATTERN = re.compile(
 )
 
 REGEX_MONTHS = """
-January|February|March|April|May|June|July|August|September|October|November|December|
-Januari|Februari|Maret|Mei|Juni|Juli|Agustus|Oktober|Desember|
-Jan|Feb|Mar|Apr|Jun|Jul|Aug|Sep|Oct|Nov|Dec|
-Januar|Jänner|Februar|Feber|März|Mai|Dezember|
-janvier|février|mars|avril|mai|juin|juillet|aout|septembre|octobre|novembre|décembre|
+January?|February?|March|A[pv]ril|Ma[iy]|Jun[ei]|Jul[iy]|August|September|O[ck]tober|November|De[csz]ember|
+Jan|Feb|M[aä]r|Apr|Jun|Jul|Aug|Sep|O[ck]t|Nov|De[cz]|
+Januari|Februari|Maret|Mei|Agustus|
+Jänner|Feber|März|
+janvier|février|mars|juin|juillet|aout|septembre|octobre|novembre|décembre|
 Ocak|Şubat|Mart|Nisan|Mayıs|Haziran|Temmuz|Ağustos|Eylül|Ekim|Kasım|Aralık|
 Oca|Şub|Mar|Nis|Haz|Tem|Ağu|Eyl|Eki|Kas|Ara
 """  # todo: check "août"
 LONG_TEXT_PATTERN = re.compile(
     rf"""(?P<month>{REGEX_MONTHS})\s
 (?P<day>[0-9]{{1,2}})(?:st|nd|rd|th)?,? (?P<year>[0-9]{{4}})|(?P<day2>[0-9]{{1,2}})(?:st|nd|rd|th|\.)? (?:of )?
-(?P<month2>{REGEX_MONTHS}),? (?P<year2>[0-9]{{4}})""".replace(
+(?P<month2>{REGEX_MONTHS})[,.]? (?P<year2>[0-9]{{4}})""".replace(
         "\n", ""
     ),
     re.I,
@@ -145,32 +145,33 @@ TEXT_MONTHS = {
     "jänner": "01",
     "january": "01",
     "januari": "01",
+    "janvier": "01",
     "jan": "01",
     "ocak": "01",
     "oca": "01",
-    "janvier": "01",
     # February
     "februar": "02",
     "feber": "02",
     "february": "02",
     "februari": "02",
+    "février": "02",
     "feb": "02",
     "şubat": "02",
     "şub": "02",
-    "février": "02",
     # March
     "märz": "03",
     "march": "03",
     "maret": "03",
     "mar": "03",
+    "mär": "03",
     "mart": "03",
     "mars": "03",
     # April
     "april": "04",
     "apr": "04",
+    "avril": "04",
     "nisan": "04",
     "nis": "04",
-    "avril": "04",
     # May
     "mai": "05",
     "may": "05",
@@ -179,38 +180,39 @@ TEXT_MONTHS = {
     # June
     "juni": "06",
     "june": "06",
+    "juin": "06",
     "jun": "06",
     "haziran": "06",
     "haz": "06",
-    "juin": "06",
     # July
     "juli": "07",
     "july": "07",
+    "juillet": "07",
     "jul": "07",
     "temmuz": "07",
     "tem": "07",
-    "juillet": "07",
     # August
     "august": "08",
     "agustus": "08",
     "aug": "08",
     "ağustos": "08",
     "ağu": "08",
-    "août": "08",
     "aout": "08",
+    # "août": "08",
     # September
     "september": "09",
+    "septembre": "09",
     "sep": "09",
     "eylül": "09",
     "eyl": "09",
-    "septembre": "09",
     # October
     "oktober": "10",
     "october": "10",
+    "octobre": "10",
     "oct": "10",
+    "okt": "10",
     "ekim": "10",
     "eki": "10",
-    "octobre": "10",
     # November
     "november": "11",
     "nov": "11",
@@ -221,10 +223,11 @@ TEXT_MONTHS = {
     "dezember": "12",
     "december": "12",
     "desember": "12",
+    "décembre": "12",
     "dec": "12",
+    "dez": "12",
     "aralık": "12",
     "ara": "12",
-    "décembre": "12",
 }
 
 TEXT_DATE_PATTERN = re.compile(r"[.:,_/ -]|^\d+$")
@@ -364,13 +367,13 @@ def regex_parse(string: str) -> Optional[datetime]:
         if match.lastgroup == "year":
             day, month, year = (
                 int(match.group("day")),
-                int(TEXT_MONTHS[match.group("month").lower()]),
+                int(TEXT_MONTHS[match.group("month").lower().strip(".")]),
                 int(match.group("year")),
             )
         else:
             day, month, year = (
                 int(match.group("day2")),
-                int(TEXT_MONTHS[match.group("month2").lower()]),
+                int(TEXT_MONTHS[match.group("month2").lower().strip(".")]),
                 int(match.group("year2")),
             )
         year = correct_year(year)
@@ -514,13 +517,11 @@ def external_date_parser(string: str, outputformat: str) -> Optional[str]:
     try:
         target = EXTERNAL_PARSER.get_date_data(string)["date_obj"]
     # 2 types of errors possible
-    except (OverflowError, ValueError) as err:
+    except (OverflowError, ValueError) as err:  # pragma: no cover
         target = None
         LOGGER.error("external parser error: %s %s", string, err)
     # issue with data type
-    if target is not None:
-        return datetime.strftime(target, outputformat)
-    return None
+    return datetime.strftime(target, outputformat) if target is not None else None
 
 
 @lru_cache(maxsize=CACHE_SIZE)
@@ -629,7 +630,7 @@ def extract_idiosyncrasy(
     try:
         parts = [0, 4, 5, 6] if match and match[6] else parts
     except IndexError:
-        pass
+        LOGGER.debug("index error in idiosyncrasies: %s", match[0])  # type: ignore[index]
     if match and parts:
         if match[parts[1]] is not None and len(match[parts[1]]) == 4:
             candidate = datetime(
