@@ -44,6 +44,8 @@ HTML_PARSER = HTMLParser(
     collect_ids=False, default_doctype=False, encoding="utf-8", remove_pis=True
 )
 
+DOCTYPE_TAG = re.compile("^< ?! ?DOCTYPE.+?/ ?>", re.I)
+
 
 def isutf8(data: bytes) -> bool:
     """Simple heuristic to determine if a bytestring uses standard unicode encoding"""
@@ -140,21 +142,31 @@ def fetch_url(url: str) -> Optional[str]:
     return None
 
 
-def is_dubious_html(htmlobject: Union[bytes, str]) -> bool:
-    "Assess if the object is proper HTML (with a corresponding declaration)."
-    if isinstance(htmlobject, bytes):
-        if (
-            "html"
-            not in htmlobject[:50].decode(encoding="ascii", errors="ignore").lower()
-        ):
-            return True
-    elif isinstance(htmlobject, str):
-        if "html" not in htmlobject[:50].lower():
-            return True
-    return False
+def is_dubious_html(beginning: str) -> bool:
+    "Assess if the object is proper HTML (awith a corresponding tag or declaration)."
+    return "html" not in beginning
 
 
-def load_html(htmlobject: HtmlElement) -> HtmlElement:
+def strip_faulty_doctypes(htmlstring: str, beginning: str) -> str:
+    "Repair faulty doctype strings to make then palatable for libxml2."
+    # libxml2/LXML issue: https://bugs.launchpad.net/lxml/+bug/1955915
+    if "doctype" in beginning:
+        firstline, _, rest = htmlstring.partition("\n")
+        return DOCTYPE_TAG.sub("", firstline, count=1) + "\n" + rest
+    return htmlstring
+
+
+def fromstring_bytes(htmlobject: str) -> Optional[HtmlElement]:
+    "Try to pass bytes to LXML parser."
+    tree = None
+    try:
+        tree = fromstring(htmlobject.encode("utf8"), parser=HTML_PARSER)
+    except Exception as err:
+        LOGGER.error("lxml parser bytestring %s", err)
+    return tree
+
+
+def load_html(htmlobject: Union[bytes, str, HtmlElement]) -> Optional[HtmlElement]:
     """Load object given as input and validate its type
     (accepted: lxml.html tree, bytestring and string)
     """
@@ -179,20 +191,26 @@ def load_html(htmlobject: HtmlElement) -> HtmlElement:
     tree = None
     # try to guess encoding and decode file: if None then keep original
     htmlobject = decode_file(htmlobject)
-    # sanity check
-    check_flag = is_dubious_html(htmlobject)
-    # use Unicode string
+    # sanity checks
+    beginning = htmlobject[:50].lower()
+    check_flag = is_dubious_html(beginning)
+    # repair first
+    htmlobject = strip_faulty_doctypes(htmlobject, beginning)
+    # first pass: use Unicode string
+    fallback_parse = False
     try:
         tree = fromstring(htmlobject, parser=HTML_PARSER)
     except ValueError:
         # "Unicode strings with encoding declaration are not supported."
-        try:
-            tree = fromstring(htmlobject.encode("utf8"), parser=HTML_PARSER)
-        except Exception as err:
-            LOGGER.error("lxml parser bytestring %s", err)
-    except Exception as err:
+        fallback_parse = True
+        tree = fromstring_bytes(htmlobject)
+    except Exception as err:  # pragma: no cover
         LOGGER.error("lxml parsing failed: %s", err)
+    # second pass: try passing bytes to LXML
+    if (tree is None or len(tree) < 2) and fallback_parse is False:
+        tree = fromstring_bytes(htmlobject)
     # rejection test: is it (well-formed) HTML at all?
+    # log parsing errors
     if tree is not None and check_flag is True and len(tree) < 2:
         LOGGER.error(
             "parsed tree length: %s, wrong data type or not valid HTML", len(tree)
